@@ -119,10 +119,13 @@ pub fn recv_mmsg(sock: &UdpSocket, packets: &mut [Packet]) -> io::Result<(usize,
 
 #[cfg(test)]
 mod tests {
-    use crate::packet::PACKET_DATA_SIZE;
-    use crate::recvmmsg::*;
-    use std::net::{SocketAddr, UdpSocket};
-    use std::time::{Duration, Instant};
+    use {
+        crate::{packet::PACKET_DATA_SIZE, recvmmsg::*},
+        std::{
+            net::{SocketAddr, UdpSocket},
+            time::{Duration, Instant},
+        },
+    };
 
     type TestConfig = (UdpSocket, SocketAddr, UdpSocket, SocketAddr);
 
